| lobpcg_control | R Documentation |
Construct a validated list of control options for the LOBPCG eigensolver
used by pca_imp(). Most users do not need to call this directly.
lobpcg_control(warmup_iters = 10L, tol = 1e-09, maxiter = 20)
warmup_iters |
Integer. Number of warm-up iterations before the main LOBPCG solve. Must be non-negative. |
tol |
Numeric. Convergence tolerance for the LOBPCG eigensolver. Must be non-negative and finite. |
maxiter |
Integer. Maximum number of LOBPCG iterations. Must be
non-negative. In |
A named list of class "slideimp_lobpcg_control" containing
warmup_iters, tol, and maxiter.
set.seed(123)
obj <- sim_mat(10, 10)$input
# Use all defaults
lobpcg_control()
# Override a single option
lobpcg_control(maxiter = 50)
# Force the exact solver from pca_imp()
pca_imp(obj, ncp = 2, solver = "exact")
# Pass directly to pca_imp()
pca_imp(obj, ncp = 2, lobpcg_control = lobpcg_control(tol = 1e-9))
# Or use a named list
pca_imp(obj, ncp = 2, lobpcg_control = list(maxiter = 50))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.