View source: R/slideimp_registry.R
| register_group_resolver | R Documentation |
Called by the companion package slideimp.extra from their .onLoad()
to register a callback that turns character manifest into a data.frame for
group_imp()/prep_groups().
register_group_resolver(resolver)
resolver |
A function that takes the manifest character and returns
a |
Invisibly returns NULL. The function is called only for its
side effect of registering the resolver.
# Typically called from `.onLoad` by `slideimp.extra` package, not by users directly.
dummy_resolver <- function(x) data.frame(feature = character(), group = character())
register_group_resolver(dummy_resolver)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.